      subroutine epSetEmin(cmpn)
c     Set Emin in ZepTrackv.h
c      From compnent #, get Emin for that compnent.
c      can be used after reading config.  typially called
c      from epLightNewcomp.f 
      use epModify
c >>>>>>>>>>>>>>>>>>>>>>>light
c      use modepLightPty
c <<<<<<<<<<<<<<<<<<<<<light
      implicit none

#include "ZepTrackp.h"
#include "ZepTrackv.h"
#include "Zcnfig.h"


      integer:: cmpn      ! component#
      integer::modi ! modifier index
c         when a particle moves  to a new component
c         the following must be done

      EminGamma =  Det.cmp(cmpn).EminG
      EminElec  =  Det.cmp(cmpn).EminE
      RecoilKEmin = Det.cmp(cmpn).RecoilE
      call epSetTcut(Media(MediaNo),  RecoilKEmin ) ! v9.154
      KEmin =  KEminsave
      EminH = Enminsave
      ImperativeEmin = .false.
      if( Det.cmp(cmpn).modifier > 0 ) then
         modi =Det.cmp(cmpn).modifier
         if( allocated ( modify ) ) then
            if( IBITS( modify(modi)%kind, bitEmin, 1) > 0) then
               KEmin = modify(modi)%Em%KEmin
               EminH = modify(modi)%Em%Enmin
               ImperativeEmin = modify(modi)%Em%imperative
c            else
c               KEmin = KEminsave
c               EminH = Enminsave
            endif
c         else
c            KEmin = KEminsave
c            EminH = Enminsave
         endif
      endif
      end
      subroutine  epSetTcut(media, RecoilKEmin)  ! 9.154
      implicit none
#include "Zmedia.h"      
      real(8),intent(in):: RecoilKEmin  ! recoil KE min GeV
      !      for histrical reason, media.sh.tcut and sh.w0 are
!      used for dEdx calculations;  Det.cmp(cn).recoilE 
!          should be directly used in better prog.
      record /epmedia/ media  !out.   media of current component
                    !  media.sh.tcut and w0 are set
      media.sh.tcut = RecoilKEmin  ! GeV
      media.sh.w0  = RecoilKEmin*1000.d0 ! MeV 
      call epResetUrban( media, media.urb)
      end

